@@ -1,5 +1,5 @@
 from pathlib import Path
-from moodle_compile.setup import importQuestions
+from moodle_compile.compile import importQuestions
 from datetime import datetime
 
 def main(root = Path("questions"), globPattern = {
